﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="CookieConstants.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2015
// </copyright>
// <summary>
//  CookieConstants helper class
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using System.Diagnostics.CodeAnalysis;

    /// <summary>
    /// Centralized location for managing all of the cookies.
    /// </summary>
    [ExcludeFromCodeCoverage]
    public static class CookieConstants
    {
        /// <summary>
        /// Cookie name for the Retail request digest.
        /// </summary>
        public static readonly string RetailRequestDigestCookieName = "rrd";

        /// <summary>
        /// Cookie name for shopping cart token for the signed-in user.
        /// </summary>
        public static readonly string SignedInShoppingCartToken = "sisct";

        /// <summary>
        /// Cookie name for checkout cart token for the signed-in user.
        /// </summary>
        public static readonly string SignedInCheckoutCartToken = "sicct";

        /// <summary>
        /// Cookie name for shopping cart token for the anonymous user.
        /// </summary>
        public static readonly string AnonymousShoppingCartToken = "sct";

        /// <summary>
        /// Cookie name for checkout cart token for the anonymous user.
        /// </summary>
        public static readonly string AnonymousCheckoutCartToken = "cct";

        /// <summary>
        /// Token to test session cookie.
        /// </summary>
        internal const string MSAXSessionCookieCheck = "MSAXSCC";

        /// <summary>
        /// Token to test regular cookie.
        /// </summary>
        internal const string MSAXPersistentCookieCheck = "MSAXPCC";

        /// <summary>
        /// Cookie name for the Default Store Channel Id.
        /// </summary>
        public static readonly string DefaultStoreChannelIdentifier = "dscid";

        /// <summary>
        /// Cookie name for the url of the product being reviewed.
        /// </summary>
        public static readonly string ProductReviewProductUrl = "ProductReviewProductUrl";

        /// <summary>
        /// Cookie name for the image url of the product being reviewed.
        /// </summary>
        public static readonly string ProductReviewImageUrl = "ProductReviewImageUrl";

        /// <summary>
        /// Cookie name for the name of the product being reviewed.
        /// </summary>
        public static readonly string ProductReviewProductName = "ProductReviewProductName";

        /// <summary>
        /// Cookie name for the description of the product being reviewed.
        /// </summary>
        public static readonly string ProductReviewProductDescription = "ProductReviewProductDescription";

        /// <summary>
        /// Cookie name for the customer id.
        /// </summary>
        public static readonly string CustomerIdToken = "cid";

        /// <summary>
        /// Cookie name for the culture Id.
        /// </summary>
        public static readonly string CultureIdToken = "cuid";
    }
}